#
# spec file for package atuin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           atuin
Version:        18.3.0
Release:        1.2
Summary:        Magical shell history
License:        MIT
Group:          System/Console
URL:            https://github.com/ellie/atuin
Source0:        https://github.com/ellie/atuin/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  cargo >= 1.77
BuildRequires:  cargo-packaging
BuildRequires:  protobuf-devel
BuildRequires:  zstd

%description
Atuin replaces your existing shell history with a SQLite database, and records additional context for your commands.
Additionally, it provides optional and fully encrypted synchronisation of your history between machines, via an Atuin server.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -a1 -p1

%build
# Omit feature "check-update" and disable defaults
%{cargo_build} --locked --no-default-features -F "client,sync,server,clipboard"

for shell in "zsh" "bash" "fish"
do
  ./target/release/%{name} gen-completions --shell "$shell" > target/%{name}."$shell"
done

%install
install -D -m 0755 "%{_builddir}/%{name}-%{version}/target/release/atuin" "%{buildroot}%{_bindir}/atuin"
install -D -m 0644 "target/%{name}.bash" "%{buildroot}/%{_datadir}/bash-completion/completions/%{name}"
install -D -m 0644 "target/%{name}.fish" "%{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish"
install -D -m 0644 "target/%{name}.zsh" "%{buildroot}/%{_datadir}/zsh/site-functions/_%{name}"

%files
%license LICENSE
%doc README.md CHANGELOG.md docs/* crates/atuin/src/shell
%{_bindir}/atuin

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Tue Jul  9 2024 Holden Fried <holdenrf2021@gmail.com>
- Fixing broken build. Needs rustc >= 1.77 and protobuf-devel
* Sat Jun 29 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 18.3.0:
  * *(bash)* Fix a workaround for bash-5.2 keybindings
  * *(ci)* Release workflow
  * *(client)* Better error reporting on login/registration
  * *(config)* Add quotes for strategy value in comment
  * *(daemon)* Do not try to sync if logged out
  * *(deps)* Replace parse_duration with humantime
  * *(dotfiles)* Alias import with init output
  * *(dotfiles)* Fish alias import
  * *(dotfiles)* More fish alias import
  * *(dotfiles)* Unquote aliases before quoting
  * *(dotfiles)* Allow clearing aliases, disable import
  * *(stats)* Generation for commands starting with a pipe
  * *(ui)* Handle being logged out gracefully
  * *(ui)* Fix mistake in last pr
  * Support not-mac for default shell
  * Adapt help to `enter_accept` config
  * Add protobuf compiler to docker image
  * Add incremental rebuild to daemon loop
  * Alias enable/enabled in settings
  * Bogus error message wording
  * Save sync time in daemon
  * Redact password in database URI when logging
  * Save sync time in daemon
  * Replace serde_yaml::to_string with serde_json::to_string_yaml
  * Fix "From source" `cd` command
  * Add docs for store subcommand
  * *(daemon)* Add support for daemon on windows
  * *(doctor)* Detect active preexec framework
  * *(doctor)* Report sqlite version
  * *(dotfiles)* Support syncing shell/env vars
  * *(gui)* Work on home page, sort state
  * *(history)* Create atuin-history, add stats to it
  * *(install)* Add Tuxedo OS
  * *(server)* Add me endpoint
  * *(ui)* Scroll history infinitely
  * *(ui)* Add history explore
  * *(ui)* Use correct username on welcome screen
  * *(ui)* Add login/register dialog
  * *(ui)* Setup single-instance
  * *(ui/dotfiles)* Add vars
  * Allow ignoring failed commands
  * Show preview auto
  * Add background daemon
  * Support importing from replxx history files
  * Move crates into crates/ dir
  * Fix atuin crate readme
  * Add some more logging to handlers
  * Add some more debug logs
  * Clarify default config file
  * Handle rate limited responses
  * Add Systemd config for self-hosted server
  * Switch to cargo dist for releases
  * Update email, gitignore, tweak ui
  * *(nushell)* Use version.(major|minor|patch) if available
  * Only open the database for commands if strictly required
  * Preview_auto to use enum and different option
* Mon Jun  3 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update specfile
  * rust+cargo -> cargo
  * set --locked flag
* Fri Apr 19 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 18.2.0:
  Bug Fixes:
  * Add missing description
  * Allow empty search
  * Pass search query in via env
  * Pass search query in via env for Nushell
  * Case insensitive hostname filtering
  * Update atuin.nu to resolve 0.92 deprecation
  * Detect preexec plugin using env ATUIN_PREEXEC_BACKEND
  * Install script echo
  * Report non-decodable errors correctly
  * Do not use "return" to cancel initialization
  * Use spawn_blocking for file access during async context
  Documentation:
  * Add security contact
  * Add install instructions for cave/exherbo linux in README.md
  * Describe the limitation of missing commands
  * Add missing cli help text
  Features:
  * Process [C-h] and [C-?] as representations of backspace
  * Allow specifying search query as an env var
  * Check PG version before running migrations
  * Add atuin prefix binding
  * Update install.sh to support KDE Neon
  * Add better search scoring
  * Sync v2 default for new installs
  * Add 'ctrl-a a' to jump to beginning of line
  * Prevents stderr from going to the screen
  * Add alias import
  * Use _ble_exec_time_ata for duration even in bash < 5
  * Add base structure
  Miscellaneous Tasks:
  * Add issue form
  * Require atuin doctor in issue form
  * Add section to issue form
  * Add codespell support (config, workflow) and make it fix some
    typos
  Performance:
  * Cache aliases and read straight from file
- Updates from 18.1.0:
  Bug Fixes
  * Rework #1509 to recover from the preexec failure
* Thu Feb 15 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- omit feature 'check-update' instead of using the removed patch 0000-disable_update_check.patch
- remove 0000-disable_update_check.patch
* Thu Feb 15 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 18.0.1:
  * Reorder the exit of enhanced keyboard mode
  * Prevent input to be interpreted as options for zsh autosuggestions
  * Avoid unexpected `atuin history start` for keybindings
  * Prevent input to be interpreted as options for blesh auto-complete
  * Work around custom IFS
  * Fix and improve the keybinding to `up`
  * Fix incorrect timing of child shells
  * Disable musl deb building
  * Work around bash < 4 and introduce initialization guards
  * Set umask 077
  * Disables unix specific stuff for windows
  * Fix invisible tab title
  * Shorten text, use ctrl-o for inspector
  * Integration on older fishes
  * Save sync time when it starts, not ends
  * Print literal control characters to non terminals
  * Escape control characters in command preview
  * Use existing db querying for history list
  * Add acquire timeout to sqlite database connection
  * Update repo url in CONTRIBUTING.md
  * Dedupe was removing history
  * Only escape control characters when writing to terminal
  * Strip control chars generated by `\[\]` in PS1 with bash-preexec
  * Check for format errors when printing history
  * Skip padding time if it will overflow the allowed prefix length
  * Never overwrite the key
  * Erase the prompt last line before Bash renders it
  * Erase the previous prompt before overwriting
  * Support termcap names for tput
  * Set durability for sqlite to recommended settings
  * Correct download list for incremental builds
  * Add Settings::ut
  * Enable enhanced keyboard mode
  * Rework record sync for improved reliability
  * Include atuin login in secret patterns
  * Add redraw
  * Make it clear what you are registering for
  * Support high-resolution timing even without ble.sh
  * Add extended help
  * Add interactive command inspector
  * Vim mode
  * Add better error handling for sync
  * Add history rebuild
  * Introduce keymap-dependent vim-mode
  * Make deleting from the UI work with record store sync
  * Add metrics counter for records downloaded
  * Make cursor style configurable
  * Make store init idempotent
  * Don't stop with invalid key
  * Add registered and deleted metrics
  * When in vim-normal mode apply an alternative highlighting to the selected line
  * [**breaking**] Bind the Atuin search to "/" in vi-normal mode
  * Update widget names
  * Make history list format configurable
  * Add change-password command & support on server
  * Automatically init history store when record sync is enabled
  * Add store push
  * Reencrypt/rekey local store
  * Add prefers_reduced_motion flag
  * Add verify command to local store
  * Add store purge command
  * Failure to decrypt history = failure to sync
  * Add `store push --force`
  * Add `store pull`
  * Disable auto record store init
  * Add progress bars to sync and store init
* Tue Jan 16 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to 17.2.1:
  Fixes:
  * Fix typo with default config
  * Don't require all fields under [stats]
  * Disallow deletion if the '--limit' flag is present
  * Fix loss of the last output line with enter_accept
  * Ignore struct_field_names
  * Improve the support for enter_accept with ble.sh
  * Fix small issues of enter_accept for the plain Bash
  * Time now_local not working
  * Fix quirks on search cancel
  * Zsh_autosuggest_strategy for no-unset environment
  * Fix error by the use of ${PS1@P} in bash < 4.4
  * Zsh use a special format to escape some characters
  * Initial list of history in workspace mode
  * Add Appkit to the package build
  * Bind in the most popular modes
  * Only trigger up-arrow on first line
  * Clean up the fish script options
  * Use fish builtins for enter_accept
  * Make atuin account delete void session + key
  * New clippy lints
  * Accept multiline commands
  * Reenable enter_accept for bash
  * Respect ZSH's $ZDOTDIR environment variable
  Documentation:
  * Add actuated linkback
  * Add link to forum
  * Align setup links in docs and readme
  * Add Void Linux install instruction
  * Add fish install script
  * Correct link
  * Fix light/dark mode logo
  * Use picture element for logo
  * Add docs for zsh-autosuggestion integration
  * Remove stray character from README
  * Update logo
  * Update sync.md
  * Update Arch Linux package URL in advanced-install.md
  * New stats config
  Features:
  * Add semver checking to client requests
  * Add TLS to atuin-server
  * Integrate with zsh-autosuggestions
  * Support high-resolution duration if available
  * Provide auto-complete source for ble.sh
  * Add a nixpkgs overlay
  * Add metrics server and http metrics
  * Add some metrics related to Atuin as an app
  * Allow configuring stats prefix
  * Allow spaces in stats prefixes
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update patch 0000-disable_update_check.patch
* Mon Oct 30 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Apply patch properly. It got overlooked.
- Update to version 17.0.1:
  * fix(enter_accept): clear old cmd snippet
  * Fix for breaking change in ratatui 0.24.0
  * fix(bash): improve output of `enter_accept`
  * fix(fish): improve output for `enter_accept`
  * update support template
  * Remove duplicate "invert" in default config
  * Silence fish string match
  * Fix cargo deb usage
  * Add release blog post and update docs
  * Correct some secrets filter regex
  * Revert "Revert "Revert "Use github runners for unit tests (for now)"""
  * fix(nushell): Ignore stderr messages
  * Document that the self-hosted port is TCP
  * Add bash support to `enter_accept`
  * allow binding server to hostname
  * Add fish support for `enter_accept`
  * Add enter_accept to immediately execute an accepted command
  * Checkout repo so the manifest publish step can read git
  * use the short sha to tag images
  * Use ubuntu for x86, oops
  * Update key binding docs
  * Add commands to print the default configuration
  * Update key-binding.md
  * Revert "Revert "Use github runners for unit tests (for now)""
  * Revert "Use github runners for unit tests (for now)"
  * clear history id
  * fix(1220): Workspace Filtermode not handled in skim engine
  * Fix/1207 deleted entries shown in interactive search
  * A man is not dead while his name is still spoken
  * Add --print0 to `history list`
  * Use github runners for unit tests (for now)
  * Revert "Re-enable `linux/arm64` platform in CI docker build"
  * Re-enable `linux/arm64` platform in CI docker build
  * feat: copy to clipboard
  * support timezones in calendar
  * handle empty keybindings list for nushell
  * add --reverse to history list
  * Fix support template
  * fix sync timestamps
  * better sync error messages
  * refactor: Duplications reduced in order to align implementations of reading history files
  * Add connect timeout and overall timeout
  * feat(keyup): Configure SearchMode for KeyUp invocation #1216
  * Fix selecting complex fish commands
  * docs: document the available format options of History list command
  * config.md: invert mode detailed options
  * Update config.toml: List inverted mode
  * Move contributors to be a top-level file
  * replace chrono with time
  * Use `case` for Linux distro choice in `install.sh`
  * Update issue templates
  * feat: mouse selection support
  * Update docker.md
  * Explicitly use buster image for cargo-chef, mitigates #1204
  * Update shell-completions.md
  * Update config.md
  * Remove fig from README
  * Automatically filter out secrets
  * Update dependencies
  * Add kv map builder and list function
  * fix(ubuntu/arm*): detect non amd64 ubuntu and handle
  * Fix keybinding link in README
  * docs: update `workspace` config key to `workspaces`
  * Only setup shell plugin if it's not already there
  * Remove terminal mode switching
  * Update to ratatui 0.22
  * Include revision in status
  * Fix index tail leak
  * Update(docs) Add `workspace` to config.toml and config.md
  * Fix client-only builds
* Wed Sep 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix and update generated vendored tarball.
* Sat Sep  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.16.0:
  * Add graceful shutdown on SIGTERM
  * Update Arch Linux links in README
  * fix: Adjust broken link to supported shells
  * feat: do not allow empty passwords durring account creation
  * Fix movement keys in inverted mode
  * Make Ctrl-d behaviour match other tools
  * refactor server to allow pluggable db and tracing
  * Add support to override hostname and username via env vars
  * Fix --delete-it-all and --delete commands
  * Make requirement of PostgreSQL 14 explicit
  * Bug/fix gh action aarch64 tarball
  * Key values
  * Add namespaces to kv store
  * Builder interface for History objects
  * clean apt cache in Dockerfile
  * remove rmp-serde
  * fix: fixes unix specific impl of shutdown_signal
  * Add RecordIndex data structure
  * remove decryption from api-client
  * Revamp getting started guide
  * Redirect old docs
  * Move key binding docs so they can be more easily found
  * record encryption
  * Fix nu section in key-bindings.md - set-env -> let-env
  * Update Nushell support to use support* remove decryption from api-client
  * Revamp getting started guide
  * Redirect old docs
  * Move key binding docs so they can be more easily found
  * record encryption
  * Fix nu section in key-bindings.md - set-env -> let-env
  * Update Nushell support to use supported $env update syntax
  * fix key encodings again
  * Update config.toml path default comments
  * fix for zsh no-unset environments
  * atuin crypto blog post
  * Add OG image
  * write some key tests
  * Add new sync
  * Add total history count to the index API
  * Delete the count cache row when a user is deleted
  * Add workspace mode, enable if in git repo
  * Unvendor ratatui
  * skim: fix filtering aggregates
  * Serve docusaurus on /docs/
  * Try adjusting docs root
  * Remove vercel config
  * Tidy up docs
  * use Ctrl-n instead of Alt-n on macOS
  * some simple server tests
  * Disable server tests in the nix build
  * Drop default sync frequency to 10m
  * Move all references to the old repo
  * Add self hosted runner
  * Split integration and unit tests, use runner for unit
  * fix(server): Teapot is a cup of coffee
  * rebase: fix: nushell empty hooks
  * Add support for max_preview_height setting
  * fix(docs): List all presently documented commands
  * encode paseto payloads as json
  * fix(docs): Correct command overview paths
  * Prepare release v16.0.0
  * fix key encodings again
  * Update config.toml path default comments
  * fix for zsh no-unset environments
  * atuin crypto blog post
  * Add OG image
  * write some key tests
  * Add new sync
  * Add total history count to the index API
  * Delete the count cache row when a user is deleted
  * Add workspace mode, enable if in git repo
  * Unvendor ratatui
  * skim: fix filtering aggregates
  * Serve docusaurus on /docs/
  * Try adjusting docs root
  * Remove vercel config
  * Tidy up docs
  * use Ctrl-n instead of Alt-n on macOS
  * some simple server tests
  * Disable server tests in the nix build
  * Drop default sync frequency to 10m
  * Move all references to the old repo
  * Add self hosted runner
  * Split integration and unit tests, use runner for unit
  * fix(server): Teapot is a cup of coffee
  * rebase: fix: nushell empty hooks
  * Add support for max_preview_height setting
  * fix(docs): List all presently documented commands
  * encode paseto payloads as json
  * fix(docs): Correct command overview paths
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Mon May 29 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 15.0.0:
  * Fix release workflow
  * Add workflow dispatch for release
  * chore: uuhhhhhh crypto lol
  * Add keyboard shortcuts to the Config/Keybinding chapter.
  * Re-added package name to workspace.package
  * Add package param to cargo deb
  * Allow specifying tag to build for workflow_dispatch
  * Add symlink
  * Upload tar before building deb
  * Copy license for cargo-deb
  * Fix fig plugin link
  * fix broken pipe on history list
  * docs: Fix broken links in README.md
  * Add nu section to keybinds.md
  * cwd_filter: much like history_filter, only it applies to cwd
  * Add command flag for inline_height
  * docs: fix "From source" cd command
  * Correct typos in website
  * website: Fix participle "be ran" -> "be run"
  * Update README.md: Disable update check for offline mode
  * At least patch this on the server side so we don't loop forever
  * Fix key regression
  * Include bash preexec warning
  * feat: add delete account option (attempt 2)
  * validate usernames on registration
  * Restructure account commands to account subcommand
  * Allow server configured page size
  * Input bar at the top if we are in inline mode
  * Add option to completely disable help row
  * Fix typo in config.toml
* Sun May  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix installation step in specfile.
* Sat Apr 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 14.0.1 patch release:
  * Fix deleting history that doesn't exist yet
  * Updated client config docs
  * Handle empty lines when importing from Bash
  * update str substring usage to use range parameter
  * Fix --delete description
  * Use XDG data directory for fish import
  * Add some emacs movement keys
  * Atuin stats with day, month, week and year filter
  * Add --reverse to atuin search
  * Add additional detail to search documentation
  * Switch to uuidv7
  * Workspace reorder
  * Improve error message for issue #850.
  * Avoid accidentally deleting all history, but allow it if intended
  * Add footer
  * Make the homepage prettier
  * Release v14.0.1
* Sat Apr 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add _constraints
  * Make disk size to 12G to fix build failure "No space left on device"
* Fri Apr 14 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 14.0.0:
  * Add Hachyderm links
  * Update flake.lock to Rust 1.67
  * nix: add flake-compat
  * Fix race condition in directory tests
  * Rework Bash import
  * docs(README): fix activity graph link
  * Show preview of selected command
  * Up arrow filter_mode setting default to global filter mode
  * feat: add common default keybindings
  * Bump debian from bullseye-20230208-slim to bullseye-20230227-slim
  * Windows support
  * fix(client): always read session_path from settings
  * Add register notification webhook
  * Install CA certificates in docker image
  * Docker isn't interactive ofc
  * Minor documentation updates
  * Fix before/after combined with limit
  * Allow specifying fulltext as well as full-text
  * fix new stats unique count
  * add common prefixes and subcommands to stats
  * fix(installer): use case-insensitive comparisons
  * Fixes a bug on windows
  * Prefer PWD environment variable over cwd if available to better support symbolic links
  * fix: many links were broken 📝
  * skim-demo
  * Add history deletion
  * fix: paste into terminal after switching modes
  * Support old msgpack
  * Fix skim search
  * Allow changing search_mode during interactive search
  * chore: remove tui vendoring
  * Bump debian from bullseye-20230227-slim to bullseye-20230320-slim
  * Delete all instances of a command
  * Bump lukemathwalker/cargo-chef from latest-rust-1.67.1 to latest-rust-1.68.0
  * feat: respect exit_mode setting when exiting with arrow down keypress
  * feat: add an inline view mode
  * Add musl build
  * feat: add Nushell support
  * chore: use fork of skim
  * Bind keys in vi mode too
  * Account for user not yet having count cache
  * Fixes nushell recording empty commands
  * Update CONTRIBUTING.md
  * client filtering done in query
  * fix: record negative exit codes
  * Refactor/nu remove dep on sh
  * Update CI
  * Add more fields to atuin search --format
  * install.sh - add endeavouros to archlinux detection
  * Add --offset flag to atuin search
  * Update atuin search docs
  * Add atuin status
  * fix: allow nix package to fetch dependencies from git
  * feat: add github action to test the nix builds
  * Vendor ratatui temporarily
* Sat Mar 25 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 13.0.1:
  * Enable RUST_BACKTRACE for docker builds
  * Revert "Re-enable arm docker builds"
  * Fix editURL for docs
  * Fix link to self-hosting
  * [docs] fix some links between config and commands
  * Disable 2 tests that shouldn't run in release mode
  * fix registration
* Mon Feb 27 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Disable update check by default since updates are handled in OBS
* Sun Feb 26 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 13.0.0:
  * Improvements
  - Better error messages
  - Nix install files + instructions
  - Exit when pushing the down arrow from the most recent entry
  - Refactor to support generic server-side databases
  - Make it easier to disable the ctrl-r and/or up arrow bindings
  - Update to axum6
  * Fixes
  - Fish now handles multi-line commands properly
  - Listing history for the current session now works
  - Fix atuin init for Fish
  * New features
  - Pretty stats
  - Custom history list format
  - History filter
  - Mnemonic key
  * Crossterm as the new TUI backend
* Thu Nov 17 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix installation of shell completions.
- Add extra shell stuff in docs.
* Sat Nov 12 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 12.0.0:
  * Allow stateless commands to be run without config/database by @c-14 in #544
  * Clear RBUFFER when accepting output from atuin by @c-14 in #545
  * Add installer support for Termux by @laurentlbm in #540
  * Bump lukemathwalker/cargo-chef from latest-rust-1.63 to latest-rust-1.64.0 by @dependabot in #546
  * Add contributors command by @ellie in #550
  * Add style to config.toml and config.md by @xfzv in #552
  * Fix compatability with fish vi key bindings by @shreve in #541
  * add some error messages by @conradludgate in #510
  * update zh-CN docs by @helbing in #539
  * Bump debian from bullseye-20220822-slim to bullseye-20221004-slim by @dependabot in #551
  * Add automatic update checking by @ellie in #555
  * Bump sqlx from 0.5.13 to 0.6.2 by @dependabot in #536
  * Bump indicatif from 0.16.2 to 0.17.1 by @dependabot in #537
  * Bump rpassword from 6.0.1 to 7.0.0 by @dependabot in #530
  * Bump tui from 0.18.0 to 0.19.0 by @dependabot in #531
  * Bump rmp-serde from 1.1.0 to 1.1.1 by @dependabot in #557
  * Bump unicode-width from 0.1.9 to 0.1.10 by @dependabot in #535
  * rollup of 5 dependency commits by @conradludgate in #562
  * Add message begging for help lol turtle by @ellie in #569
  * upgrade clap by @conradludgate in #568
  * Configure reqwest to use native platform certs by @wpbrz in #574
  * Bump async-trait from 0.1.57 to 0.1.58 by @dependabot in #575
  * Never use HISTFILE for fish shell import by @patricksjackson in #573
  * Respect fish shell's builtin private mode by @patricksjackson in #577
  * Bump clap from 4.0.15 to 4.0.18 by @dependabot in #578
  * docs: add more details about date parsing in the stats command by @bvergnaud in #579
  * Make fuzzy search the default by @ellie in #591
  * Update server.md by @pevogam in #589
  * Exit with return code 1 when no results are found in atuin search command by @TymanWasTaken in #489
  * Update README.md with antigen instruction. by @DanielAtCosmicDNA in #549
  * Build ARM64 releases & update runners by @Absolucy in #593
  * Add local event log storage by @ellie in #390
  * fix #596: Avoid drawing a command section beyond the width of the list by @s0 in #597
  * Add setting for keeping typed query when exiting by @s0 in #451
  * Fix copy/paste artifact by @EricCrosson in #598
  * Release v12 by @ellie in #599
* Tue Oct 11 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Add shell completion packages
* Thu Oct  6 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Set rust+cargo version at least 1.59.
* Thu Sep 29 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec of atuin version 11.0.0
